<template>
  <LoadingLayout :loading="state.loading">
    <AppContainer>
      <ProTableQueryFilterBar @on-reset="reset">
        <template #query>
          <QueryFilterItem tip-content="申请时间">
            <FieldDatePicker
              v-model="extraParamState.dateTime"
              type="daterange"
              range-separator="~"
              start-placeholder="开始日期"
              end-placeholder="结束日期"
              clearable
              @change="getList()"
            ></FieldDatePicker>
          </QueryFilterItem>
          <QueryFilterItem tip-content="审核状态">
            <FieldRadio
              v-model="extraParamState.checkStatus"
              :value-enum="EnterpriseRechargeStatusEnumText"
              buttonStyle
              showAllBtn
              @change="getList()"
            />
          </QueryFilterItem>
          <QueryFilterItem>
            <SearchInput
              v-model="extraParamState.keyWord"
              style="width: 300px"
              placeholder="企业名称/园区/信用代码"
              @on-click-search="getList"
            >
            </SearchInput>
          </QueryFilterItem>
        </template>
      </ProTableQueryFilterBar>

      <ProTableV2 v-bind="proTableProps" :columns="column" :operationBtns="operationBtns">
      </ProTableV2>
      <WithdrawalApprovalAuditDialog v-bind="dialogProps"></WithdrawalApprovalAuditDialog>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import {
  LoadingLayout,
  AppContainer,
  useTable,
  ProTableQueryFilterBar,
  ProTableV2,
  defineOperationBtns,
  SearchInput,
  FieldRadio,
  QueryFilterItem,
  FieldDatePicker,
  useFormDialog,
  UploadUserFile,
} from '@bole-core/components';
import { Message, OrderInputType } from '@bole-core/core';
import { format } from '@/utils';
import { EnterpriseRechargeStatusEnum, EnterpriseRechargeStatusEnumText } from '@/constants';
import * as parkBountyApplyServices from '@/services/api/ParkBountyApply';
import WithdrawalApprovalAuditDialog from './components/WithdrawalApprovalAuditDialog.vue';
import _ from 'lodash';
import { ModelValueType } from 'element-plus';

defineOptions({
  name: 'WithdrawalApproval',
});

const column: API.CustomModuleColumnDto[] = [
  {
    id: '1',
    enCode: 'enterpriseName',
    name: '企业名称',
  },
  {
    id: '2',
    enCode: 'societyCreditCode',
    name: '统一社会信用代码',
  },
  {
    id: '3',
    enCode: 'enterpriseType',
    name: '企业类型',
  },
  {
    id: '4',
    enCode: 'parkName',
    name: '所属园区',
  },
  {
    id: '5',
    enCode: 'parkType',
    name: '园区类型',
  },
  {
    id: '6',
    enCode: 'creationTime',
    name: '申请时间',
  },
  {
    id: '7',
    enCode: 'amount',
    name: '申请提现金额（元）',
  },
  {
    id: '8',
    enCode: 'checkStatus',
    name: '审核状态',
  },
  {
    id: '9',
    enCode: 'checkTime',
    name: '审核时间',
  },
];

const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'detailBtn',
      name: '详情',
    },
    emits: {
      onClick: (role) => openDialog(role, true),
    },
    extraProps: {
      hide: (row: API.GetEnterpriseDrawWithListOutput) =>
        row.checkStatus === EnterpriseRechargeStatusEnum.WaitCheck,
    },
  },
  {
    data: {
      enCode: 'auditBtn',
      name: '审核',
    },
    emits: {
      onClick: (role) => openDialog(role),
    },
    extraProps: {
      hide: (row: API.GetEnterpriseDrawWithListOutput) =>
        row.checkStatus !== EnterpriseRechargeStatusEnum.WaitCheck,
    },
  },
]);

const router = useRouter();
const BaseState = {
  loading: true,
};

const state = reactive({ ...BaseState });

onMounted(async () => {
  await getList();
  state.loading = false;
});

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.GetEnterpriseDrawWithListInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        keyWord: extraParamState.keyWord,
        checkStatus: extraParamState.checkStatus,
        beginDateTime: format(extraParamState.dateTime?.[0] ?? '', 'YYYY-MM-DD 00:00:00'),
        endDateTime: format(extraParamState.dateTime?.[1] ?? '', 'YYYY-MM-DD 23:59:59'),
      };
      let res = await parkBountyApplyServices.getEnterpriseDrawWithList(params, {
        showLoading: !state.loading,
      });
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      keyWord: '',
      checkStatus: '' as any as EnterpriseRechargeStatusEnum,
      dateTime: [] as unknown as ModelValueType,
      orderInput: [{ property: 'creationTime', order: OrderInputType.Desc }],
    },
    columnsRenderProps: {
      creationTime: { type: 'date', format: 'YYYY-MM-DD HH:mm:ss' },
      checkTime: { type: 'date', format: 'YYYY-MM-DD HH:mm:ss' },
      amount: { type: 'money' },
      checkStatus: { type: 'enum', valueEnum: EnterpriseRechargeStatusEnumText },
    },
  }
);

function openDialog(row: API.GetEnterpriseDrawWithListOutput, isCheck = false) {
  handleAdd({
    drawWithId: row.drawWithId,
    isCheck,
  });
}

const { dialogProps, handleAdd, handleEdit, editForm } = useFormDialog({
  onConfirm: handleAddOrEdit,
  defaultFormParams: {
    drawWithId: '',
    checkStatus: '' as any as EnterpriseRechargeStatusEnum,
    checkRemark: '',
    isCheck: false,
    checkFileUrl: [] as UploadUserFile[],
  },
});

async function handleAddOrEdit() {
  try {
    let params: API.CheckEnterpriseApplyDrawWithInput = {
      applyDrawWithId: editForm.drawWithId,
      checkStatus: editForm.checkStatus,
      checkFileUrl: editForm.checkFileUrl?.length > 0 ? editForm.checkFileUrl[0].path : '',
      checkRemark: editForm.checkRemark,
    };
    let res = await parkBountyApplyServices.checkEnterpriseApplyDrawWith(params);
    if (res) {
      Message.successMessage('操作成功');
      getList(paginationState.pageIndex);
    }
  } catch (error) {}
}
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
